@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2012 by Dominique Dumont.
+# This software is Copyright (c) 2007-2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -40,24 +40,12 @@
                 type       => 'leaf',
                 level      => 'hidden',
                 value_type => 'uniline',
-                experience => 'advanced',
                 warp       => {
                     follow  => { 't'            => '?type' },
                     'rules' => [ '$t eq "hash"' => { level => 'normal', } ]
                 }
             },
 
-            [ qw/migrate_keys_from/ ] => {
-                type       => 'leaf',
-                level      => 'hidden',
-                value_type => 'uniline',
-                experience => 'advanced',
-                warp       => {
-                    follow  => { 't'                            => '?type' },
-                    'rules' => [ '$t eq "hash" or $t eq "list"' => { level => 'normal', } ]
-                }
-            },
-
             [qw/ordered/] => {
                 type       => 'leaf',
                 level      => 'hidden',
@@ -75,7 +63,6 @@
                 type       => 'list',
                 level      => 'hidden',
                 cargo      => { type => 'leaf', value_type => 'string' },
-                experience => 'advanced',
                 warp       => {
                     follow  => { 't'            => '?type' },
                     'rules' => [ '$t eq "hash"' => { level => 'normal', } ]
@@ -86,7 +73,6 @@
                 type       => 'leaf',
                 level      => 'hidden',
                 value_type => 'string',
-                experience => 'advanced',
                 warp       => {
                     follow  => { 't'            => '?type' },
                     'rules' => [ '$t eq "list"' => { level => 'normal', } ]
@@ -118,7 +104,6 @@
                 type       => 'hash',
                 index_type => 'string',
                 level      => 'hidden',
-                experience => 'advanced',
                 warp       => {
                     follow  => { 't' => '?type' },
                     'rules' => [
@@ -163,15 +148,14 @@
         ],
 
         'description' => [
-            follow_keys_from => 'this hash will contain the same keys as the hash pointed by the path string',
-            allow_keys_from => 'this hash will allow keys from the keys of the hash pointed by the path string',
+            follow_keys_from => 'this hash contains the same keys as the hash pointed by the path string',
+            allow_keys_from => 'this hash allows keys from the keys of the hash pointed by the path string',
             ordered => 'keep track of the order of the elements of this hash',
             default_keys => 'default keys hashes.',
             auto_create_keys => 'always create a set of keys specified in this list',
             auto_create_ids => 'always create the number of id specified in this integer',
             allow_keys => 'specify a set of allowed keys',
             allow_keys_matching => 'Keys must match the specified regular expression.',
-            migrate_keys_from => 'Specifies that the keys of the hash or list are copied from another hash or list in the configuration tree only when the hash is created.',
             default_with_init => 'specify a set of keys to create and initialization on some elements . E.g. \' foo => "X=Av Y=Bv", bar => "Y=Av Z=Cz"\' ',
             help => 'Specify help string specific to possible values. E.g for "light" value, you could write " red => \'stop\', green => \'walk\' ',
             replace => 'Used for enum to substitute one value with another. This parameter must be used to enable user to upgrade a configuration with obsolete values. The old value is the key of the hash, the new one is the value of the hash',
